@@ -14,6 +14,7 @@ use JSON::MaybeXS ();
 use Module::Load qw/ load /;
 use Package::Stash;
 use Ref::Util qw/ is_scalarref /;
+use Sub::Identify qw/ is_sub_constant /;
 use Try::Tiny;
 use Types::Common::String qw/ NonEmptySimpleStr /;
 use Types::Standard qw/ ArrayRef Bool HashRef InstanceOf /;
@@ -25,7 +26,7 @@ use Types::Standard qw/ ArrayRef Bool HashRef InstanceOf /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 option use_var => (
@@ -185,6 +186,7 @@ sub _import_to_symbol {
     else {
         my $fn  = $self->get_symbol( '&' . $import )
             or croak "Cannot find symbol '${import}' in " . $self->module;
+        is_sub_constant($fn) or carp "Symbol '${import}' is not a constant in " . $self->module;
         my $val = $fn->();
         return ( $import => $val );
     }
@@ -206,7 +208,7 @@ JavaScript::Const::Exporter - Convert exported Perl constants to JavaScript
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -264,6 +266,10 @@ L</module>'s namespace to export.
 If it is omitted (not recommened), then it will look at the modules
 C<@EXPORT_OK> list an export all modules.
 
+Any subroutine can be included, however if the subroutine is not not a
+coderef constant, e.g. created by L<constant>, then it will emit a
+warning.
+
 You must include sigils of constants. However, the exported JavaScript
 will omit them, e.g. C<$NAME> will export JavaScript that specifies a
 constant called C<NAME>.
